###############################################################################
# ContactPage.pm                                                              #
###############################################################################
# YaBB: Yet another Bulletin Board                                            #
# Open-Source Community Software for Webmasters                               #
# Version:        YaBB 2.7.00                                                 #
# Distributed by: http://www.yabbforum.com                                    #
# =========================================================================== #
# Copyright (c) 2000-2017 YaBB (www.yabbforum.com) - All Rights Reserved.     #
# Software by:  The YaBB Development Team                                     #
#               with assistance from the YaBB community.                      #
###############################################################################
use strict;
no strict qw(refs);
use warnings;
use CGI::Carp qw(fatalsToBrowser);
our $VERSION = '2.7.00';

our $contactpagepmver = 'YaBB 2.7.00 $Revision: 0.11 $';
our ($action);
$action ||= q{};
if ( $action eq 'detailedversion' ) { return 1; }

#System
our (
    $abbr_lang,        $adminurl,            $invalmailchar,
    $invalemaila,      $invalemailb,         $iamadmin,
    $date,             $iamgmod,             $iamguest,
    $iammod,           $langdir,             $mbname,
    $post_speed_count, $scripturl,           $spam_hits_left_count,
    $spam_image,       $uid,                 $user_ip,
    $username,         $vardir,              $webmaster_email,
    $yyhtml_root,      $yyinlinestyle,       $yymain,
    $staff,            $yysetlocation,       $spam_question,
    $spam_question_id, $spam_questions_case, $language,
    %FORM,             $imp_email_check,     $boardurl,
);

our (
    $autores_email,   $autores_name,            $autores_pre,
    $contact_auto,    $contact_email,           $contact_subjects,
    $contactform,     $contactform_autorespond, $contactform_selfcopy,
    $en_contact_auto, $en_contactpage,          $en_selfcopy,
    $en_valimage,     $en_valquest,             $maxconmeslen,
    $my_flood,        $my_selfcopy,             $my_spamq,
    $mycontactsend,   $selfcopy_email,          $selfcopy_name,
    $selfcopy_pre,    $showcheck,               $subject_pre,
    %contact_txt,     %contactpre_txt,          $my_contact_email2,
    %mail_check,
);

require Sources::SpamCheck;

if ( -e ("$vardir/Mods/ContactPage.txt") ) {
    require "$vardir/Mods/ContactPage.txt";
}

if ( $en_valimage
    && ( $en_valimage == 2 || ( $iamguest && $en_valimage == 1 ) ) )
{
    require Sources::Decoder;
}

if ( !$en_contactpage || ( $iamguest && $en_contactpage != 1 ) ) {
    fatal_error('not_allowed');
}

load_language('Mods/ContactPage');
get_template('Mods/ContactPage');

sub Contact {
    my $contactuser  = q{};
    my $contactemail = q{};
    if ( !$iamguest ) {
        $contactuser =
qq~ value="${$uid.$username}{'realname'}" onfocus="txtInFields(this, '${$uid.$username}{'realname'}');" onblur="txtInFields(this, '${$uid.$username}{'realname'}')"~;
        $contactemail =
qq~ value="${$uid.$username}{'email'}" onfocus="txtInFields(this, '${$uid.$username}{'email'}');" onblur="txtInFields(this, '${$uid.$username}{'email'}')"~;
    }
    my $email2 = q{};
    if ($imp_email_check) {
        if ( eval { require Net::DNS } ) {
            $email2 = $my_contact_email2;
            $email2 =~ s/\Q{yabb email2}\E/$contact_txt{'70'}/xsm;
        }
    }

    my $check_other = q{};
    if ($contact_subjects) {
        $check_other = q~ onfocus="CheckOtherSubject();"~;
    }

    my @subjectoptions = split /[|]/xsm, $contact_subjects;
    my $subjectcount   = 0;
    my $subjects       = q{};
    foreach (@subjectoptions) {
        $subjects .=
qq~<label for="contact_subject$subjectcount"><input type="radio" name="contact_subject" id="contact_subject$subjectcount" value="$subjectcount" />$_</label><br />\n~;
        $subjectcount++;
    }

    my $mycontact_subjects = q{};
    if ($contact_subjects) {
        $mycontact_subjects = qq~
                <label for="other"><input type="radio" name="contact_subject" id="other" value="other" onclick="FocusOtherSubject();" />$contact_txt{'06'}</label><br />~;
    }

    my $mycontact_selfcopy = q{};
    if ($en_selfcopy) {
        $mycontact_selfcopy = $my_selfcopy;
    }
    my $contact_flood = q{};
    if ( $en_valimage
        && ( $en_valimage == 2 || ( $iamguest && $en_valimage == 1 ) ) )
    {
        validation_code();
        $contact_flood = $my_flood;
        $contact_flood =~ s/\Q{yabb showcheck}\E/$showcheck/gxsm;
    }
    my $contact_spam = q{};
    if (
        -e "$langdir/$language/spam.questions"
        && ( $en_valquest
            && ( $en_valquest == 2 || ( $iamguest && $en_valquest == 1 ) ) )
      )
    {
        spam_question();
        my $verification_question_desc = q{};
        if ($spam_questions_case) {
            $verification_question_desc =
              qq~<br />$contact_txt{'verification_question_case'}~;
        }
        $contact_spam .= $my_spamq;
        $contact_spam =~ s/\Q{yabb spam_question}\E/$spam_question/gxsm;
        $contact_spam =~
s/\Q{yabb verification_question_desc}\E/$verification_question_desc/gxsm;
        $contact_spam =~ s/\Q{yabb spam_question_id}\E/$spam_question_id/gxsm;
        $contact_spam =~ s/\Q{yabb spam_image}\E/$spam_image/gxsm;
    }

    $yymain .= $mycontactsend;
    $yymain =~ s/\Q{yabb contactuser}\E/$contactuser/gxsm;
    $yymain =~ s/\Q{yabb contactemail}\E/$contactemail/gxsm;
    $yymain =~ s/\Q{yabb contactemail2}\E/$email2/gxsm;
    $yymain =~ s/\Q{yabb subjects}\E/$subjects/gxsm;
    $yymain =~ s/\Q{yabb contact_subjects}\E/$mycontact_subjects/gxsm;
    $yymain =~ s/\Q{yabb check_other}\E/$check_other/gxsm;
    $yymain =~ s/\Q{yabb maxconmeslen}\E/$maxconmeslen/gxsm;
    $yymain =~ s/\Q{yabb mycontact_selfcopy}\E/$mycontact_selfcopy/gxsm;
    $yymain =~ s/\Q{yabb contact_flood}\E/$contact_flood/gxsm;
    $yymain =~ s/\Q{yabb contact_spam}\E/$contact_spam/gxsm;

    $yymain .= q~
<script type="text/javascript">

    if (document.contact.your_name.value == '') {
        document.contact.your_name.focus();
    }~ . (
        $contact_subjects
        ? q~
    function CheckOtherSubject() {
        document.getElementById('other').checked = true;
    }
    function FocusOtherSubject() {
        if (document.getElementById('other').checked == true) {
            document.contact.other_contact_subject.focus();
        }
    }~
        : q{}
      )
      . qq~
function CheckContactFields() {
if (document.contact.your_name.value == '') {
    alert("$contact_txt{'12'}");
    document.contact.your_name.focus();
    return false;
}
if (document.contact.your_email.value == '') {
    alert("$contact_txt{'13'}");
    document.contact.your_email.focus();
    return false;
}~ . (
        $contact_subjects
        ? qq~
var subjects = 0;
for (var i=0; i < document.contact.contact_subject.length; i++) {
     if (document.contact.contact_subject[i].checked == true) {
         subjects++;
         break;
     }
}
if (subjects == 0) {
    alert("$contact_txt{'14'}");
    document.getElementById('other').checked = true
    document.contact.other_contact_subject.focus();
    return false;
}
if (document.getElementById('other').checked == true && document.contact.other_contact_subject.value == '') {
    alert("$contact_txt{'15'}");
    document.contact.other_contact_subject.focus();
    return false;
}~
        : qq~
if (document.contact.other_contact_subject.value == '') {
    alert("$contact_txt{'15'}");
    document.contact.other_contact_subject.focus();
    return false;
}~
      ) . qq~
if (document.contact.message.value == '') {
    alert("$contact_txt{'16'}");
    document.contact.message.focus();
    return false;
}~ . (
        $en_valquest == 2 || ( $iamguest && $en_valquest == 1 )
        ? qq~
if (document.contact.verification_question.value == '') {
    alert("$contact_txt{'17a'}");
    document.contact.verification_question.focus();
    return false;
}~
        : q{}
      )
      . (
        $en_valimage == 2 || ( $iamguest && $en_valimage == 1 )
        ? qq~
if (document.contact.verification.value == '') {
    alert("$contact_txt{'17'}");
    document.contact.verification.focus();
    return false;
}~
        : q{}
      )
      . qq~
return true;
}

var supportsKeys = false;
function tick() {
    calcCharLeft(document.forms[0]);
    if (!supportsKeys) { timerID = setTimeout("tick()", 1500); }
}
function calcCharLeft() {
clipped = false;
maxLength = $maxconmeslen;
if (document.contact.message.value.length > maxLength) {
    document.contact.message.value = document.contact.message.value.substring(0,maxLength);
    charleft = 0;
    clipped = true;
} else {
    charleft = maxLength - document.contact.message.value.length;
}
document.contact.msgCL.value = charleft;
return clipped;
}
tick();
</script>
~;

    our $yytitle      = "$contact_txt{'01'}";
    our $yynavigation = qq~&rsaquo; $contact_txt{'01'}~;
    template();
    return;
}

sub ContactSend {
    require Sources::Mailer;
    load_language('Email');

    my $yourname            = $FORM{'your_name'};
    my $youremail           = $FORM{'your_email'};
    my $contactsubject      = $FORM{'contact_subject'} || q{};
    my $othercontactsubject = $FORM{'other_contact_subject'};
    my $contactmessage      = $FORM{'message'};
    my $contactselfcopy     = $FORM{'contact_selfcopy'};
    $yourname =~ s/\A\s+//xsm;
    $yourname =~ s/\s+\Z//xsm;
    $youremail =~ s/\A\s+//xsm;
    $youremail =~ s/\s+\Z//xsm;
    $contactsubject =~ s/\A\s+//xsm;
    $contactsubject =~ s/\s+\Z//xsm;
    $othercontactsubject =~ s/\A\s+//xsm;
    $othercontactsubject =~ s/\s+\Z//xsm;
    $contactmessage =~ s/\r(?=\n*)//gxsm;
    $contact_auto =~ s/<br\s\/>/\n/gxsm;

    $contact_email  ||= $webmaster_email;
    $selfcopy_email ||= $webmaster_email;
    $autores_email  ||= $webmaster_email;
    $selfcopy_name  ||= $mbname;
    $autores_name   ||= $mbname;
    $subject_pre    ||= "$contactpre_txt{'01'}";
    $selfcopy_pre   ||= "$contactpre_txt{'02'}";
    $autores_pre    ||= "$contactpre_txt{'03'}";

    my @subjectoptions = split /[|]/xsm, $contact_subjects;
    my $subject = q{};
    if ( $contactsubject eq 'other' || !$contact_subjects ) {
        $subject = $othercontactsubject;
    }
    else { $subject = $subjectoptions[$contactsubject]; }

    if ( $yourname eq q{} )       { fatal_error('no_name'); }
    if ( length($yourname) > 50 ) { fatal_error('sendname_too_long'); }
    if ( !$youremail || $youremail eq q{} ) { fatal_error('no_email'); }
    if ( $youremail !~ /^$invalmailchar$/xsm ) {
        fatal_error( 'invalid_character', "$contact_txt{'04'}." );
    }
    if (   $youremail =~ /$invalemaila/xsm
        || $youremail !~ /$invalemailb/xsm )
    {
        fatal_error('invalid_email');
    }

    if ( length($youremail) > 100 ) { fatal_error('email_to_long'); }
    if ( $imp_email_check && $youremail ne $FORM{'email2'} ) {
        fatal_error('email_mismatch');
    }
    if ( $imp_email_check == 1 ) {
        if ( eval { require Net::DNS } ) {
            require Mail::CheckUser;
            Mail::CheckUser->import(qw(check_email last_check));
            $Mail::CheckUser::Sender_Addr = $webmaster_email;
            if ( $boardurl =~ /http\:\/\/(.*?)\//xsm ) {
                $Mail::CheckUser::Helo_Domain = $1;
            }
            if ( check_email($youremail) ) {
                my $email_ok = 1;
            }
            else {
                my $failure = last_check()->{code};
                fatal_error( q{},
"$mail_check{'address'} $youremail $mail_check{'invalid'} $mail_check{'reason'} $mail_check{$failure}"
                );
            }
        }
    }
    if ( $contact_subjects && $contactsubject eq q{} ) {
        fatal_error('no_subject');
    }
    if (   $contact_subjects
        && $contactsubject eq 'other'
        && $othercontactsubject eq q{} )
    {
        fatal_error('no_subject');
    }
    if ( !$contact_subjects && !$othercontactsubject ) {
        fatal_error('no_subject');
    }
    if ( !$contactmessage ) { fatal_error('no_message'); }

    # Spam detection start
    email_domain_check($youremail);

    # Check if poster isn't using a distilled email domain
    my ( $spamdetected, $spamword ) =
      spamcheck("$yourname $youremail $othercontactsubject $contactmessage");
    if ($username) {
        if ( !${ $uid . $username }{'spamcount'} ) {
            ${ $uid . $username }{'spamcount'} = 0;
        }
        if ( !$staff ) {
            if ( $spamdetected == 1 && $username ) {
                ${ $uid . $username }{'spamcount'}++;
                ${ $uid . $username }{'spamtime'} = $date;
                user_account( $username, 'update' );
                $spam_hits_left_count =
                  $post_speed_count - ${ $uid . $username }{'spamcount'};
            }
        }
    }
    if ( $spamdetected == 1 && !$staff ) { fatal_error('tsc_alert'); }

    # Spam detection end

    if ( $en_valimage
        && ( $en_valimage == 2 || ( $iamguest && $en_valimage == 1 ) ) )
    {
        validation_check( $FORM{'verification'} );
    }
    if (
        -e "$langdir/$language/spam.questions"
        && ( $en_valquest
            && ( $en_valquest == 2 || ( $iamguest && $en_valquest == 1 ) ) )
      )
    {
        spam_question_check( $FORM{'verification_question'},
            $FORM{'verification_question_id'} );
    }

    my $contact_message = template_email(
        $contactform,
        {
            'yourname'       => $yourname,
            'contactsubject' => $subject,
            'contactmessage' => $contactmessage,
            'youremail'      => $youremail,
            'contactip'      => $user_ip
        }
    );
    sendmail(
        $contact_email,   "$subject_pre: $subject",
        $contact_message, "$yourname <$youremail>"
    );

    if ( $contactselfcopy && $en_selfcopy ) {
        my $copy_message = template_email(
            $contactform_selfcopy,
            {
                'yourname'       => $yourname,
                'contactsubject' => $subject,
                'contactmessage' => $contactmessage,
                'youremail'      => $youremail
            }
        );
        sendmail(
            $youremail,    "$selfcopy_pre: $subject",
            $copy_message, "$selfcopy_name <$selfcopy_email>"
        );
    }

    if ( $en_contact_auto && $contact_auto ) {
        my $autores_message = template_email( $contactform_autorespond,
            { 'autoresponse' => $contact_auto } );
        sendmail(
            $youremail,       "$autores_pre: $subject",
            $autores_message, "$autores_name <$autores_email>"
        );
    }

    $yymain .= qq~
    <table class="tabtitle pad_4px">
        <tr>
            <th style="padding-left:1%"><img src="$yyhtml_root/ModImages/contact.gif" alt="" /> $contact_txt{'01'} $mbname </th>
        </tr>
    </table>
    <table class="bordercolor pad_4px cs_thin">
        <tr>
            <td class="windowbg center" style="padding: 20px;">
                <span style="font-weight: bold;">$contact_txt{'18'} $yourname.<br />$contact_txt{'19'}</span><br /><br />
                &bull; <a href="$scripturl">$contact_txt{'20'}</a><br /><br />
                <span class="small">$contact_txt{'21'}</span>
            </td>
        </tr>
    </table>~;

    $yyinlinestyle =
      qq~<meta http-equiv="refresh" content="5; url=$scripturl" />~;
    our $yytitle = "$contact_txt{'01'} - $contact_txt{'22'}";
    our $yynavigation =
      qq~&rsaquo; $contact_txt{'01'} &rsaquo; $contact_txt{'22'}~;
    template();
    return;
}

1;
